# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/vidgyor/livefeeds/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/vidgyor/livefeeds/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "Vidgyor\\Livefeeds\\": "packages/vidgyor/livefeeds/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Vidgyor\Livefeeds\Providers\LivefeedsServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Livefeeds'  => Vidgyor\Livefeeds\Facades\Livefeeds::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Vidgyor\\LivefeedsTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Vidgyor\Livefeeds\Providers\LivefeedsServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Vidgyor\Livefeeds\Providers\LivefeedsServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Vidgyor\Livefeeds\Providers\LivefeedsServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/livefeeds/{modulename}

**User**

    http://path-to-route-folder/user/livefeeds/{modulename}

**Public**

    http://path-to-route-folder/livefeeds


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/livefeeds/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/livefeeds/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/livefeeds/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/livefeeds/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/livefeeds/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/livefeeds/{modulename}/{slug}
    METHOD: GET