<?php

namespace Vidgyor\Livefeeds\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use Vidgyor\Livefeeds\Http\Requests\LiveFeedRequest;
use Vidgyor\Livefeeds\Interfaces\LiveFeedRepositoryInterface;
use Vidgyor\Livefeeds\Models\LiveFeed;
use Vidgyor\Livefeeds\Forms\LiveFeed as Form;

/**
 * APIController  class for live_feed.
 */
class LiveFeedAPIController extends BaseController
{

    /**
     * Initialize live_feed resource controller.
     *
     * @param type LiveFeedRepositoryInterface $live_feed
     *
     * @return null
     */
    public function __construct(LiveFeedRepositoryInterface $live_feed)
    {
        parent::__construct();
        $this->repository = $live_feed;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Vidgyor\Livefeeds\Repositories\Criteria\LiveFeedResourceCriteria::class);
    }

    /**
     * Display a list of live_feed.
     *
     * @return Response
     */
    public function index(LiveFeedRequest $request)
    {
        return $this->repository
            ->setPresenter(\Vidgyor\Livefeeds\Repositories\Presenter\LiveFeedPresenter::class)
            ->paginate();
    }

    /**
     * Display live_feed.
     *
     * @param Request $request
     * @param Model   $live_feed
     *
     * @return Response
     */
    public function show(LiveFeedRequest $request, LiveFeed $live_feed)
    {
        return $live_feed->setPresenter(\Vidgyor\Livefeeds\Repositories\Presenter\LiveFeedListPresenter::class);
        ;
    }

    /**
     * Create new live_feed.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(LiveFeedRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('livefeeds::live_feed.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('livefeeds/live_feed/' . $live_feed->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('livefeeds/live_feed');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the live_feed.
     *
     * @param Request $request
     * @param Model   $live_feed
     *
     * @return Response
     */
    public function update(LiveFeedRequest $request, LiveFeed $live_feed)
    {
        try {
            $data = $request->all();

            $live_feed->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('livefeeds::live_feed.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('livefeeds/live_feed/' . $live_feed->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('livefeeds/live_feed/' . $live_feed->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the live_feed.
     *
     * @param Model   $live_feed
     *
     * @return Response
     */
    public function destroy(LiveFeedRequest $request, LiveFeed $live_feed)
    {
        try {
            $live_feed->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('livefeeds::live_feed.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('livefeeds/live_feed/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('livefeeds/live_feed/' . $live_feed->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
