<?php

namespace Vidgyor\Livefeeds\Policies;

use Litepie\User\Contracts\UserPolicy;
use Vidgyor\Livefeeds\Models\LiveFeed;

class LiveFeedPolicy
{

    /**
     * Determine if the given user can view the live_feed.
     *
     * @param UserPolicy $user
     * @param LiveFeed $live_feed
     *
     * @return bool
     */
    public function view(UserPolicy $user, LiveFeed $live_feed)
    {
        if ($user->canDo('livefeeds.live_feed.view') && $user->isAdmin()) {
            return true;
        }

        return $live_feed->user_id == user_id() && $live_feed->user_type == user_type();
    }

    /**
     * Determine if the given user can create a live_feed.
     *
     * @param UserPolicy $user
     * @param LiveFeed $live_feed
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('livefeeds.live_feed.create');
    }

    /**
     * Determine if the given user can update the given live_feed.
     *
     * @param UserPolicy $user
     * @param LiveFeed $live_feed
     *
     * @return bool
     */
    public function update(UserPolicy $user, LiveFeed $live_feed)
    {
        if ($user->canDo('livefeeds.live_feed.edit') && $user->isAdmin()) {
            return true;
        }

        return $live_feed->user_id == user_id() && $live_feed->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given live_feed.
     *
     * @param UserPolicy $user
     * @param LiveFeed $live_feed
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, LiveFeed $live_feed)
    {
        return $live_feed->user_id == user_id() && $live_feed->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given live_feed.
     *
     * @param UserPolicy $user
     * @param LiveFeed $live_feed
     *
     * @return bool
     */
    public function verify(UserPolicy $user, LiveFeed $live_feed)
    {
        if ($user->canDo('livefeeds.live_feed.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given live_feed.
     *
     * @param UserPolicy $user
     * @param LiveFeed $live_feed
     *
     * @return bool
     */
    public function approve(UserPolicy $user, LiveFeed $live_feed)
    {
        if ($user->canDo('livefeeds.live_feed.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
