<?php

namespace Vidgyor\Livefeeds\Providers;

use Illuminate\Support\ServiceProvider;

class LivefeedsServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'livefeeds');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'livefeeds');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerLivefeeds();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerLivefeeds()
    {
        $this->app->bind('livefeeds', function($app) {
            return new Livefeeds($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('Livefeeds', 'Lavalite\Livefeeds\Facades\Livefeeds');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('vidgyor.livefeeds', function ($app) {
            return $this->app->make('Vidgyor\Livefeeds\Livefeeds');
        });

                // Bind LiveFeed to repository
        $this->app->bind(
            'Vidgyor\Livefeeds\Interfaces\LiveFeedRepositoryInterface',
            \Vidgyor\Livefeeds\Repositories\Eloquent\LiveFeedRepository::class
        );

        $this->app->register(\Vidgyor\Livefeeds\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Vidgyor\Livefeeds\Providers\RouteServiceProvider::class);
            }

    /**
     * Merges user's and livefeeds's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'vidgyor.livefeeds'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeLivefeeds::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['vidgyor.livefeeds'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('vidgyor/livefeeds.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/livefeeds')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/livefeeds')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
